@@ -1,36 +1,38 @@
 # @package      hubzero-submit-client
 # @file         JobScanner.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
-# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# @license      http://opensource.org/licenses/MIT MIT
 #
-# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 #
-# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
-# software: you can redistribute it and/or modify it under the terms of
-# the GNU Lesser General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any
-# later version.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
-# HUBzero is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-
 import sys
 import os
 import os.path
 import math
 import re      # Regexp: http://docs.python.org/library/re.html
 import traceback
+import logging
 
 import curses # <-- docs at: http://docs.python.org/library/curses.html
 import curses.ascii   # <-- docs at http://docs.python.org/library/curses.ascii.html
@@ -42,9 +44,11 @@ import csv
 
 import textwrap
 
-# ===============
+from hubzero.submit.LogMessage import getLogIDMessage as getLogMessage
+
 class SearchBoard:
    def __init__(self, nrow, ncol):
+      self.logger = logging.getLogger(__name__)
       self.hit   = empty( (nrow, ncol), dtype=bool)
       self.dirty =  ones( (nrow, ncol), dtype=bool)
 
@@ -80,6 +84,7 @@ class SearchBoard:
 
 class Point:
    def __init__(self, argX, argY):
+      self.logger = logging.getLogger(__name__)
       self.x = argX
       self.y = argY
 
@@ -93,6 +98,7 @@ class Point:
 
 class Size:
    def __init__(self, argWidth, argHeight):
+      self.logger = logging.getLogger(__name__)
       self.width  = argWidth
       self.height = argHeight
 
@@ -107,6 +113,7 @@ class AGW_File_Data_Collection:
    Sorry for the confusion.
    '''
    def __init__(self):
+      self.logger = logging.getLogger(__name__)
       self.collection = [] # <-- contants: a bunch of AGW_File_Data objects
       self.currentFileIdx = None # which one are we currently looking at?
                                  # probably should be not part of the object, come to think of it.
@@ -131,6 +138,7 @@ class AGW_File_Data_Collection:
 
 class AGW_File_Data:
    def __init__(self, argFilename):
+      self.logger = logging.getLogger(__name__)
       self.filename = argFilename
       self.table = AGW_Table()
       self.defaultCellProperty = curses.A_NORMAL #REVERSE
@@ -230,6 +238,7 @@ class AGW_File_Data:
 # =======================================
 class AGW_Win:
    def __init__(self):
+      self.logger = logging.getLogger(__name__)
       self.win = None
       self.pos = Point(0,0) # where is the top-left of this window?
       self.windowWidth = 0
@@ -294,6 +303,7 @@ class AGW_Win:
 ## Data window (the main window with the cells in it)
 class AGW_DataWin(AGW_Win):
    def __init__(self, isSearchable=False):
+      self.logger = logging.getLogger(__name__)
       AGW_Win.__init__(self) # parent constructor
       self.info = None
       self.defaultCellProperty = curses.A_NORMAL #REVERSE
@@ -344,7 +354,7 @@ class AGW_DataWin(AGW_Win):
             ch = curses.ACS_ULCORNER
          elif (c == rightCol):
             ch = curses.ACS_URCORNER
-         else:       
+         else:
             ch = curses.ACS_TTEE
       elif (r == bottomRow):
          if (c == 0):
@@ -486,7 +496,7 @@ class AGW_DataWin(AGW_Win):
                   self.win.hline(cellTextPos.y-1, cellTextPos.x, curses.ACS_HLINE, hLineLength)
                except:
                   print("problem when cellTextPos is y=" + str(cellTextPos.y-1) +
-                        ", x=" + str(cellTextPos.x) + 
+                        ", x=" + str(cellTextPos.x) +
                         " and also the rows and cols are " + str(r) + " and " + str(c))
                   raise
 
@@ -527,6 +537,7 @@ class AGW_DataWin(AGW_Win):
 
 class AGW_Table:
    def __init__(self):
+      self.logger = logging.getLogger(__name__)
       self.clearTable()
       self.currentFile = None
       self.currentFilename = None
@@ -559,7 +570,7 @@ class AGW_Table:
 
    def getColWidth(self, colIdx):
       ## Report out how wide each column is
-      try: 
+      try:
          if (self.colWidth[colIdx] > self.MAX_COL_WIDTH):
             return self.MAX_COL_WIDTH
          else:
@@ -631,10 +642,13 @@ class AGW_Table:
       ## We want to see which file we should read from.
       ## 1. We either got a HYPHEN, which is the UNIX shorthand for "read from STDIN"
       ## 2. or we got a real filename, in which case we try to read the file from the filesystem
-      self.currentFile = open(theFilename, 'rb')
-
-      self.csvReader = csv.reader(self.currentFile)
-      self.currentFilename = theFilename
+      try:
+         self.currentFile = open(theFilename,'rb')
+      except (IOError,OSError):
+         self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (theFilename)))
+      else:
+         self.csvReader = csv.reader(self.currentFile)
+         self.currentFilename = theFilename
 
 
    def closeCurrentFile(self):
@@ -688,13 +702,14 @@ class AGW_Table:
 
       self.clearTable()
 
-      self.currentFile = open(theFilename, 'rb')
-
-      self.csvReader = csv.reader(self.currentFile)
-
-      self.currentFilename = theFilename
-
-      self.readFromCurrentFile(previousCurrentNumLinesLoaded)
+      try:
+         self.currentFile = open(theFilename,'rb')
+      except (IOError,OSError):
+         self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (theFilename)))
+      else:
+         self.csvReader = csv.reader(self.currentFile)
+         self.currentFilename = theFilename
+         self.readFromCurrentFile(previousCurrentNumLinesLoaded)
 
 
 class JobScanner:
@@ -726,6 +741,7 @@ in order for you to be able to run statussheet.py!
 
    def __init__(self,
                 jobScanPath):
+      self.logger = logging.getLogger(__name__)
       self.ROW_HEADER_MAXIMUM_COLUMN_FRACTION_OF_SCREEN = 0.25 # The row header column (i.e., the leftmost column)
                                                                # cannot be any wider than this fraction of the total screen width.
                                                                # 1.0 means "do not change--it can be the entire screen,"
@@ -1012,7 +1028,7 @@ in order for you to be able to run statussheet.py!
                               ,("      [^/$/g/G]: Go to left/right/top/bottom of table  [x]: Examine Result ")
                               , lineAttr)
 
-      self.helpWin.win.refresh()    
+      self.helpWin.win.refresh()
 
 
    def drawQuestionWin(self):
@@ -1027,8 +1043,8 @@ in order for you to be able to run statussheet.py!
          self.questionWin.safeAddStr(2,xQuestion,questionStr)
          self.questionWin.safeAddStr(3,xQuestion+xActionStatement,actionStatement)
 
-         self.questionWin.win.border()    
-         self.questionWin.win.refresh()    
+         self.questionWin.win.border()
+         self.questionWin.win.refresh()
 
    #
    #
@@ -1117,7 +1133,7 @@ in order for you to be able to run statussheet.py!
             self.infoWin.safeAddStr(SUBMIT_COMPLETED_ROW, column, gaugeIncomplete, curses.A_NORMAL)
             column += gaugeIncompleteWidth
             self.infoWin.safeAddStr(SUBMIT_COMPLETED_ROW, column, "]", curses.A_NORMAL)
- 
+
       commandStr1 = "" + self.stringFromAny(self.commandStr)
       self.infoWin.safeAddStr(COMMAND_ROW, 0, commandStr1, curses.A_NORMAL)
 
@@ -1191,10 +1207,16 @@ in order for you to be able to run statussheet.py!
                if len(matchingFiles) > 0:
                   for matchingFile in matchingFiles:
                      stdoutPath = os.path.join(resultPath,matchingFile)
-                     fpResult = open(stdoutPath,'r')
-                     if fpResult:
-                        stdoutText += [x.strip() for x in fpResult.readlines()]
-                        fpResult.close()
+                     try:
+                        fpResult = open(stdoutPath,'r')
+                        try:
+                           stdoutText += [x.strip() for x in fpResult.readlines()]
+                        except (IOError,OSError):
+                           self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (stdoutPath)))
+                        finally:
+                           fpResult.close()
+                     except (IOError,OSError):
+                        self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stdoutPath)))
             except:
                stdoutPath = None
 
@@ -1206,10 +1228,16 @@ in order for you to be able to run statussheet.py!
                if len(matchingFiles) > 0:
                   for matchingFile in matchingFiles:
                      stderrPath = os.path.join(resultPath,matchingFile)
-                     fpResult = open(stderrPath,'r')
-                     if fpResult:
-                        stderrText += [x.strip() for x in fpResult.readlines()]
-                        fpResult.close()
+                     try:
+                        fpResult = open(stderrPath,'r')
+                        try:
+                           stderrText += [x.strip() for x in fpResult.readlines()]
+                        except (IOError,OSError):
+                           self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (stderrPath)))
+                        finally:
+                           fpResult.close()
+                     except (IOError,OSError):
+                        self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (stderrPath)))
             except:
                stderrPath = None
 
@@ -1368,8 +1396,8 @@ in order for you to be able to run statussheet.py!
    def handleKeysForQuestionMode(self, argCh, currentTable):
       ## If we are in question mode, then when the user types, the question is answered.
 
-      KEYS_QUESTION_MODE_YES = (ord('y'), ord('Y') ) 
-      KEYS_QUESTION_MODE_NO  = (ord('n'), ord('N') ) 
+      KEYS_QUESTION_MODE_YES = (ord('y'), ord('Y') )
+      KEYS_QUESTION_MODE_NO  = (ord('n'), ord('N') )
 
       if   argCh in KEYS_QUESTION_MODE_YES:
          self.questionFunc(True)
